@@ -66,7 +66,7 @@ class JwtManager:
             assert ObjectHelper.isDictionary(decodedSessionToken), f'Invalid session type. It should be a dictionary, bu it is {type(decodedSessionToken)}'
             assert ObjectHelper.isNotEmpty(decodedSessionToken), 'Session cannot be empty'
             assert not decodedSessionToken[JwtConstant.KW_JTI] in BLACK_LIST, f'Session {decodedSessionToken[JwtConstant.KW_JTI]} already closed'
-            assert UtcDateTimeHelper.now() < UtcDateTimeHelper.ofTimestamp(rawJwt.get(JwtConstant.KW_EXPIRATION)), f'JWT token expired at {UtcDateTimeHelper.ofTimestamp(rawJwt.get(JwtConstant.KW_EXPIRATION))}. Time now: {UtcDateTimeHelper.now()}, rawJwt: {rawJwt}'
+            assert UtcDateTimeUtil.now() < UtcDateTimeUtil.ofTimestamp(rawJwt.get(JwtConstant.KW_EXPIRATION)), f'JWT token expired at {UtcDateTimeUtil.ofTimestamp(rawJwt.get(JwtConstant.KW_EXPIRATION))}. Time now: {UtcDateTimeUtil.now()}, rawJwt: {rawJwt}'
         except Exception as exception:
             addUserToBlackList(rawJwt=decodedSessionToken)
             raise exception
@@ -181,12 +181,12 @@ def addJwt(jwtInstance) :
 
 @EncapsulateItWithGlobalException(message=JwtConstant.INVALID_SESSION_MESSAGE, status=HttpStatus.UNAUTHORIZED)
 def createAccessToken(identity, contextList, deltaMinutes=0, headers=None, data=None, apiInstance=None):
-    timeNow = UtcDateTimeHelper.now()
+    timeNow = UtcDateTimeUtil.now()
     return retrieveApiInstance(apiInstance=apiInstance).sessionManager.encode({
             JwtConstant.KW_IAT: timeNow,
             JwtConstant.KW_NFB: timeNow,
             JwtConstant.KW_JTI: getNewJti(),
-            JwtConstant.KW_EXPIRATION: UtcDateTimeHelper.plusMinutes(timeNow, minutes=deltaMinutes),
+            JwtConstant.KW_EXPIRATION: UtcDateTimeUtil.plusMinutes(timeNow, minutes=deltaMinutes),
             JwtConstant.KW_IDENTITY: identity,
             JwtConstant.KW_FRESH: False,
             JwtConstant.KW_TYPE: JwtConstant.ACCESS_VALUE_TYPE,
@@ -200,12 +200,12 @@ def createAccessToken(identity, contextList, deltaMinutes=0, headers=None, data=
 
 @EncapsulateItWithGlobalException(message=JwtConstant.INVALID_SESSION_MESSAGE, status=HttpStatus.UNAUTHORIZED)
 def refreshAccessToken(identity, contextList, deltaMinutes=0, headers=None, data=None, apiInstance=None):
-    timeNow = UtcDateTimeHelper.now()
+    timeNow = UtcDateTimeUtil.now()
     return retrieveApiInstance(apiInstance=apiInstance).sessionManager.encode({
             JwtConstant.KW_IAT: timeNow,
             JwtConstant.KW_NFB: timeNow,
             JwtConstant.KW_JTI: getJti(apiInstance=apiInstance),
-            JwtConstant.KW_EXPIRATION: UtcDateTimeHelper.plusMinutes(timeNow, minutes=deltaMinutes),
+            JwtConstant.KW_EXPIRATION: UtcDateTimeUtil.plusMinutes(timeNow, minutes=deltaMinutes),
             JwtConstant.KW_IDENTITY: identity,
             JwtConstant.KW_FRESH: False,
             JwtConstant.KW_TYPE: JwtConstant.REFRESH_VALUE_TYPE,
@@ -220,8 +220,6 @@ def refreshAccessToken(identity, contextList, deltaMinutes=0, headers=None, data
 @EncapsulateItWithGlobalException(message=JwtConstant.INVALID_SESSION_MESSAGE, status=HttpStatus.UNAUTHORIZED)
 def patchAccessToken(newContextList=None, headers=None, data=None, apiInstance=None):
     rawJwt = getJwtBody(apiInstance=apiInstance)
-    expiresAt = getExpiration(rawJwt=rawJwt, apiInstance=apiInstance)
-    UtcDateTimeHelper.now()
     userClaims = {
         JwtConstant.KW_CONTEXT: list(set([
             *getContext(rawJwt=rawJwt),
@@ -241,7 +239,7 @@ def patchAccessToken(newContextList=None, headers=None, data=None, apiInstance=N
             JwtConstant.KW_IAT: getIat(rawJwt=rawJwt, apiInstance=apiInstance),
             JwtConstant.KW_NFB: getNfb(rawJwt=rawJwt, apiInstance=apiInstance),
             JwtConstant.KW_JTI: getJti(rawJwt=rawJwt, apiInstance=apiInstance),
-            JwtConstant.KW_EXPIRATION: expiresAt,
+            JwtConstant.KW_EXPIRATION: getExpiration(rawJwt=rawJwt, apiInstance=apiInstance),
             JwtConstant.KW_IDENTITY: getIdentity(rawJwt=rawJwt, apiInstance=apiInstance),
             JwtConstant.KW_FRESH: False,
             JwtConstant.KW_TYPE: JwtConstant.ACCESS_VALUE_TYPE,
