@@ -8,11 +8,11 @@ def timestamp():
     return datetime.datetime.timestamp()
 
 def ofTimestamp(t):
-    return datetime.datetime.fromtimestamp(t)
-
-def ofUtcTimestamp(t):
     return datetime.datetime.utcfromtimestamp(t)
 
+def ofPlainTimestamp(t):
+    return datetime.datetime.fromtimestamp(t)
+
 def plusMinutes(givenDateTime, minutes=None, deltaInMinutes=None) :
     if ObjectHelper.isNotNone(minutes) :
         deltaInMinutes = DateTimeHelper.timeDelta(seconds=minutes*60)
